<?php
/*
  $Id: ht_hide_boxes.php
  $Loc: catalog/includes/modules/header_tags/

  Hide Boxes 1.3
  by @raiwa
  raiwa@phoenixcartaddons.com
  www.phoenixcartaddons.com

  Copyright (c) 2020 Rainer Schmied

  CE Phoenix, E-Commerce made Easy
  https://phoenixcart.org

  Copyright (c) 2021 Phoenix Cart

  Released under GNU License
*/

  class ht_hide_boxes extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_HEADER_TAGS_HIDE_BOXES_';

    public function __construct() {
      parent::__construct(__FILE__);

    }

    function execute() {

      if (!Text::is_empty(MODULE_HEADER_TAGS_HIDE_BOXES_BOXES)) {
        $boxes_array = explode(';', MODULE_HEADER_TAGS_HIDE_BOXES_BOXES);
        $script = null;
        foreach ($boxes_array as $box) {
          $box = str_replace('_', '-', $box);
          $script .= <<<EOD
var element = document.getElementsByClassName('{$box}')[0];
if (element) {
  element.classList.add('d-none','d-md-block');
}
EOD
 . PHP_EOL;
        }

        $GLOBALS['Template']->add_block('<script>' . PHP_EOL . $script . '</script>' . PHP_EOL, 'footer_scripts');
      }
    }

    protected function get_parameters() {
      return [
        'MODULE_HEADER_TAGS_HIDE_BOXES_STATUS' => [
          'title' => 'Hide Boxes',
          'value' => 'True',
          'desc' => 'Do you want to add HIde Boxes to your shop?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_HEADER_TAGS_HIDE_BOXES_BOXES' => [
          'title' => 'Boxes',
          'value' => '',
          'desc' => 'Tick the boxes to hide on mobile.',
          'set_func' => 'ht_hide_boxes_edit_boxes(',
          'use_func' => 'ht_hide_boxes_show_boxes',
        ],
        'MODULE_HEADER_TAGS_HIDE_BOXES_SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '1000',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
      ];
    }

  } // end class

  function ht_hide_boxes_show_boxes($text) {
    return nl2br(implode("\n", explode(';', $text)));
  }

  function ht_hide_boxes_edit_boxes($values, $key) {

    $inst_array = str_replace('.php', '', explode(';', MODULE_BOXES_INSTALLED));

    sort($inst_array);

    $values_array = explode(';', $values);

    $output = '';
    foreach ($inst_array as $file) {
      if ( in_array($file, $values_array) ) {
        $output .= new Tickable('ht_hide_boxes_file[]', ['value' => $file, 'checked' => 'checked'], 'checkbox') . '&nbsp;' . Text::output($file) . '<br />';
      } else {
        $output .= new Tickable('ht_hide_boxes_file[]', ['value' => $file], 'checkbox') . '&nbsp;' . Text::output($file) . '<br />';
      }
    }

    if (!empty($output)) {
      $output = '<br>' . substr($output, 0, -6);
    }

    $output .= new Input('configuration[' . $key . ']', ['id' => 'htrn_files'], 'hidden');

    $output .= <<<EOD
<script>
  function htrn_update_cfg_value() {
    var htrn_selected_files = '';

    var checkboxes = document.querySelectorAll('input[name="ht_hide_boxes_file[]"]');
    if (checkboxes.length > 0) {
      checkboxes.forEach(function(checkbox) {
        if (checkbox.checked) {
          htrn_selected_files += checkbox.value + ';';
        }
      });

      if (htrn_selected_files.length > 0) {
        htrn_selected_files = htrn_selected_files.substring(0, htrn_selected_files.length - 1);
      }
    }

    document.getElementById('htrn_files').value = htrn_selected_files;
  }

  document.addEventListener('DOMContentLoaded', function() {
    htrn_update_cfg_value();

    var checkboxes = document.querySelectorAll('input[name="ht_hide_boxes_file[]"]');
    if (checkboxes.length > 0) {
      checkboxes.forEach(function(checkbox) {
        checkbox.addEventListener('change', function() {
          htrn_update_cfg_value();
        });
      });
    }
  });
  </script>
EOD;

    return $output;
  }
